ProjectEnvironment

Struct ProjectEnvironment 

pub struct ProjectEnvironment { /* private fields */ }
Represents a generic Rust/Cargo project’s environment.

Implementations

Source

impl ProjectEnvironment

pub fn new<T, U>(manifest_dir: T, crate_name: U) -> ProjectEnvironment
where T: Into<PathBuf>, U: Into<String>,

Creates a new instance using the given manifest dir and crate name.

pub fn new_from_env() -> Option<ProjectEnvironment>

Creates a new instance using the the CARGO_MANIFEST_DIR and CARGO_CRATE_NAME environment variables.

pub fn determine_ethers_crates( &self, ) -> Option<HashMap<EthersCrate, &'static str>>

Determines the crate paths to use by looking at the metadata of the project.

The names will be:

  • ethers::* if ethers is a dependency for all crates;
  • for each crate:
    • ethers_<crate> if it is a dependency, otherwise ethers::<crate>.
pub fn is_crate_root(&self) -> bool

Returns whether the crate path identifier refers to the root package.

This is false for integration tests, benches, and examples, as the crate keyword will not refer to the root package.

We can find this using some environment variables set by Cargo during compilation:

  • CARGO_TARGET_TMPDIR is only set when building integration test or benchmark code;
  • When CARGO_MANIFEST_DIR contains /benches/ or /examples/
  • CARGO_CRATE_NAME, see is_crate_name_in_dirs.
pub fn is_crate_name_in_dirs(&self) -> bool

Returns whether crate_name is the name of a file or directory in the first level of manifest_dir/{benches,examples,tests}/.

Example

With this project structure:

.
├── Cargo.lock
├── Cargo.toml
├── src/
│   ...
├── benches/
│   ├── large-input.rs
│   └── multi-file-bench/
│       ├── main.rs
│       └── bench_module.rs
├── examples/
│   ├── simple.rs
│   └── multi-file-example/
│       ├── main.rs
│       └── ex_module.rs
└── tests/
    ├── some-integration-tests.rs
    └── multi-file-test/
        ├── main.rs
        └── test_module.rs

The resulting CARGO_CRATE_NAME values will be:

PathValue
benches/large-input.rslarge-input
benches/multi-file-bench/**/*.rsmulti-file-bench
examples/simple.rssimple
examples/multi-file-example/**/*.rsmulti-file-example
tests/some-integration-tests.rssome-integration-tests
tests/multi-file-test/**/*.rsmulti-file-test