pub enum DecoderError {
RlpIsTooBig,
RlpIsTooShort,
RlpExpectedToBeList,
RlpExpectedToBeData,
RlpIncorrectListLen,
RlpDataLenWithZeroPrefix,
RlpListLenWithZeroPrefix,
RlpInvalidIndirection,
RlpInconsistentLengthAndData,
RlpInvalidLength,
Custom(&'static str),
}Expand description
Error concerning the RLP decoder.
Variants
RlpIsTooBig
Data has additional bytes at the end of the valid RLP fragment.
RlpIsTooShort
Data has too few bytes for valid RLP.
RlpExpectedToBeList
Expect an encoded list, RLP was something else.
RlpExpectedToBeData
Expect encoded data, RLP was something else.
RlpIncorrectListLen
Expected a different size list.
RlpDataLenWithZeroPrefix
Data length number has a prefixed zero byte, invalid for numbers.
RlpListLenWithZeroPrefix
List length number has a prefixed zero byte, invalid for numbers.
RlpInvalidIndirection
Non-canonical (longer than necessary) representation used for data or list.
RlpInconsistentLengthAndData
Declared length is inconsistent with data specified after.
RlpInvalidLength
Declared length is invalid and results in overflow
Custom(&'static str)
Custom rlp decoding error.